package pg.android.activity;

import pg.android.kernel.Bluetooth;
import pg.android.kernel.Device;
import pg.android.kernel.DeviceContainer;
import pg.android.kernel.Protocol;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.SeekBar;
import android.widget.SeekBar.OnSeekBarChangeListener;
import android.widget.TextView;
import android.widget.Toast;

public class AktorActivity extends Activity {
	private TextView deviceNummer;
	private TextView deviceType;
	private TextView deviceSubType;
	private TextView deviceName;
	private TextView dataType;
	private TextView bitDepth;
	private TextView scale;
	private TextView minValue;
	private TextView maxValue;
	private TextView curValue;
	private Button button;
	private SeekBar seekbar;
	private CheckBox checkbox;
	
	private int nummer;
	private Device device = null;
	
    private final BroadcastReceiver broadcastReceiver = new BroadcastReceiver() {
		@Override
		public void onReceive(Context context, Intent intent) {
			String action = intent.getAction();
			
			if (action.equals("VALUECHANGED")) {
				
				if (nummer == intent.getExtras().getInt("DeviceNumber")) {
					Logger.add("recieve VALUECHANGED");
					Device device = DeviceContainer.get(nummer);
					if (device == null){
			        	Toast toast = Toast.makeText(getApplicationContext(), "Sensor nicht gefunden", Toast.LENGTH_SHORT);
			        	toast.show();
						finish();
					}
					curValue.setText(Float.toString(device.getValue()));					
				}				
			}
		}
    };
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.aktoractivitylayout);
		
		Bundle extras = getIntent().getExtras();
		nummer = extras.getInt("DeviceNummer");
		
		device = DeviceContainer.get(nummer);
		if (device == null){
        	Toast toast = Toast.makeText(getApplicationContext(), "Sensor nicht gefunden", Toast.LENGTH_SHORT);
        	toast.show();
			finish();
		}
		
		deviceNummer = (TextView)findViewById(R.id.v_number);
		deviceNummer.setText(Integer.toString(nummer));
		
		deviceType = (TextView)findViewById(R.id.v_type);
		deviceType.setText("Aktor");
		
		deviceSubType = (TextView)findViewById(R.id.v_subtype);
		deviceSubType.setText(Protocol.Aktors.get(device.getSubType()));
		
		deviceName = (TextView)findViewById(R.id.v_name);
		deviceName.setText(device.name);
		
		dataType = (TextView)findViewById(R.id.v_datatype);
		dataType.setText(Protocol.DataTypes.get(device.dataType));
		
		bitDepth = (TextView)findViewById(R.id.v_bitdepth);
		bitDepth.setText(Integer.toHexString(device.bitDepth & 0xFF));
		
		scale = (TextView)findViewById(R.id.v_scale);
		scale.setText(Integer.toHexString(device.scale & 0xFF));
		
		minValue = (TextView)findViewById(R.id.v_min);
		minValue.setText(Float.toString(device.minValue));

		maxValue = (TextView)findViewById(R.id.v_max);
		maxValue.setText(Float.toString(device.maxValue));

		curValue = (TextView)findViewById(R.id.v_cur);
		curValue.setText(Float.toString(device.getValue()));
		
		button = (Button)findViewById(R.id.button1);
		button.setOnClickListener(new OnClickListener() {			
			@Override
			public void onClick(View v) {				
				if (device.bitDepth == 1) {
					showDialog(1);
				} else {
					showDialog(0);
				}				
			}
		});
		
		registerReceiver(broadcastReceiver,new IntentFilter("VALUECHANGED"));
	}


	@Override
	protected Dialog onCreateDialog(int id) {
	    	Context mContext = getApplicationContext();
	    	LayoutInflater inflater = (LayoutInflater) mContext.getSystemService(LAYOUT_INFLATER_SERVICE);
	    	AlertDialog.Builder builder = null;

	    	switch (id) {
	    	default:
	    		final View layout = inflater.inflate(R.layout.aktordialog, (ViewGroup) findViewById(R.id.layout_root));
		    	TextView value = (TextView)layout.findViewById(R.id.textView1);
		    	value.setText("" + device.getValue());
		    	seekbar = (SeekBar)layout.findViewById(R.id.seekBar1);
		    	seekbar.setProgress((int)(device.getValue() - device.getMin()));
		    	seekbar.setMax((int)device.getRange());
		    	
		    	seekbar.setOnSeekBarChangeListener(new OnSeekBarChangeListener() {
					
					@Override
					public void onStopTrackingTouch(SeekBar seekBar) {
						// TODO Auto-generated method stub
						
					}
					
					@Override
					public void onStartTrackingTouch(SeekBar seekBar) {
						// TODO Auto-generated method stub
						
					}
					
					@Override
					public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
						
						TextView tvalue = (TextView)layout.findViewById(R.id.textView1);
						tvalue.setText("" + (int)(device.getMin() + progress));
						
						
	    	   			float range = device.maxValue - device.minValue;
	    				float bitScale = (float) (Math.pow(2, device.bitDepth) - 1);
	    				int value = seekbar.getProgress();

	    				value = (int)((value) * bitScale / range);
	    				
						Bluetooth.getValuePacketToSend = true;	    				
	    				Bluetooth.getValuePacket = Protocol.SetDeviceValue(nummer, value);
					}
				});	   
		    	

		    	//seek	    	
		    	builder = new AlertDialog.Builder(this);
		    	builder.setMessage(getResources().getString(R.string.set_value));
		    	builder.setCancelable(false);
		    	builder.setView(layout);
		    	/*
		    	builder.setPositiveButton(getResources().getString(R.string.set), new DialogInterface.OnClickListener() {
		    	           public void onClick(DialogInterface dialog, int id) {
		    	        	   
		    	   			float range = device.maxValue - device.minValue;
		    				float bitScale = (float) (Math.pow(2, device.bitDepth) - 1);
		    				int value = seekbar.getProgress();

		    				value = (int)((value) * bitScale / range);
		    				
							Bluetooth.getValuePacketToSend = true;	    				
		    				Bluetooth.getValuePacket = Protocol.SetDeviceValue(nummer, value);
		    	           }
		    	       });
		    	*/
		    	builder.setNegativeButton(getResources().getString(R.string.cancel), new DialogInterface.OnClickListener() {
		    	           public void onClick(DialogInterface dialog, int id) {
		    	                dialog.cancel();
		    	           }
		    	       });

				return builder.create();
	    	case 1: // bittiefe 1
	    		final View layout_check = inflater.inflate(R.layout.aktordialog1, (ViewGroup) findViewById(R.id.layout_root));
		    	TextView value_check = (TextView)layout_check.findViewById(R.id.textView1);
		    	value_check.setText("" + device.getValue());
		    	checkbox = (CheckBox)layout_check.findViewById(R.id.checkBox1);
		    	if (device.getValue() != 0){
		    		checkbox.setChecked(true);
		    	} else {
		    		checkbox.setChecked(false);
		    	}
		    	
		    	checkbox.setOnCheckedChangeListener(new OnCheckedChangeListener() {
					
					@Override
					public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
						TextView tvalue = (TextView)layout_check.findViewById(R.id.textView1);
						if (isChecked == true) {
							tvalue.setText("1.0");
							Bluetooth.getValuePacketToSend = true;	    				
		    				Bluetooth.getValuePacket = Protocol.SetDeviceValue(nummer, 1);
						} else {
							tvalue.setText("0.0");
							Bluetooth.getValuePacketToSend = true;	    				
		    				Bluetooth.getValuePacket = Protocol.SetDeviceValue(nummer, 0);
						}

					}
				});
		    	
		    	builder = new AlertDialog.Builder(this);
		    	builder.setMessage(getResources().getString(R.string.set_value));
		    	builder.setCancelable(false);
		    	builder.setView(layout_check);

		    	builder.setNegativeButton(getResources().getString(R.string.cancel), new DialogInterface.OnClickListener() {
	    	           public void onClick(DialogInterface dialog, int id) {
	    	                dialog.cancel();
	    	           }
	    	       });
		    	
				return builder.create();    	

	    	}
	}

	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		
		//connection.cancel();
		unregisterReceiver(broadcastReceiver);
	}
}
